@@ -950,12 +950,12 @@ class Permissions(CommonColumns):
                 user_email_list.append(user.email)
                 grant_lister_access(user.email)
 
-        grant_download_access(user_email_list, upload.trial_id, upload.upload_type)
-
-        if upload.upload_type in prism.SUPPORTED_MANIFESTS:
+        if upload.upload_type in prism.SUPPORTED_SHIPPING_MANIFESTS:
             # Passed with empty user email list because they will be queried for in CFn
             grant_download_access([], upload.trial_id, "participants info")
             grant_download_access([], upload.trial_id, "samples info")
+        elif upload.upload_type not in prism.SUPPORTED_WEIRD_MANIFESTS:
+            grant_download_access(user_email_list, upload.trial_id, upload.upload_type)
 
     @staticmethod
     @with_default_session
